import { SignJWT } from 'jose';
import fs from 'fs';
import { isKeyLike, keyFormatErrorMessage } from "../../util/jwt-util.mjs";
import { createPrivateKey } from 'crypto';
export function sign(payload, secretOrPrivateKey, options) {
    const sign = new SignJWT({
        ...payload,
        ...(options.keyid ? { kid: options.keyid } : null),
    }).setProtectedHeader({ alg: options.algorithm || 'RS256' });
    if (options.issuer)
        sign.setIssuer(options.issuer);
    if (options.subject)
        sign.setSubject(options.subject);
    if (options.audience)
        sign.setAudience(options.audience);
    if (options.notBefore)
        sign.setNotBefore(options.notBefore);
    if (options.expiresIn)
        sign.setExpirationTime(options.expiresIn);
    return sign.sign(secretOrPrivateKey);
}
export function getSigningKey(mux, opts) {
    const keyId = opts.keyId || mux.jwtSigningKey;
    if (!keyId) {
        throw new Error('Signing key required; pass a keyId option to mux.jwt.sign*(), a jwtSigningKey option to new Mux(), or set the MUX_SIGNING_KEY environment variable');
    }
    return keyId;
}
export async function getPrivateKey(mux, opts) {
    const key = await getPrivateKeyHelper(mux, opts);
    if (isKeyLike(key))
        return key;
    return createPrivateKey(key);
}
async function getPrivateKeyHelper(mux, opts) {
    let key;
    if (opts.keySecret) {
        key = opts.keySecret;
    }
    else if (opts.keyFilePath) {
        key = await fs.promises.readFile(opts.keyFilePath, 'utf8');
    }
    else if (mux.jwtPrivateKey) {
        key = mux.jwtPrivateKey;
    }
    if (Buffer.isBuffer(key) || isKeyLike(key))
        return key;
    if (typeof key === 'string') {
        key = key.trim();
        if (key.startsWith('-----BEGIN')) {
            return key;
        }
        try {
            key = Buffer.from(key, 'base64').toString();
            if (key.startsWith('-----BEGIN')) {
                return key;
            }
        }
        catch (err) {
            // fallthrough
        }
        throw new TypeError(keyFormatErrorMessage);
    }
    throw new TypeError('Private key required; pass a keySecret or keyFilePath option to mux.jwt.sign*(), a jwtPrivateKey option to new Mux(), or set the MUX_PRIVATE_KEY environment variable');
}
//# sourceMappingURL=jwt-node.mjs.map