"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPrivateKey = exports.getSigningKey = exports.sign = void 0;
const jose_1 = require("jose");
const jwt_util_1 = require("../../util/jwt-util.js");
function sign(payload, secretOrPrivateKey, options) {
    const sign = new jose_1.SignJWT({
        ...payload,
        ...(options.keyid ? { kid: options.keyid } : null),
    }).setProtectedHeader({ alg: options.algorithm || 'RS256' });
    if (options.issuer)
        sign.setIssuer(options.issuer);
    if (options.subject)
        sign.setSubject(options.subject);
    if (options.audience)
        sign.setAudience(options.audience);
    if (options.notBefore)
        sign.setNotBefore(options.notBefore);
    if (options.expiresIn)
        sign.setExpirationTime(options.expiresIn);
    return sign.sign(secretOrPrivateKey);
}
exports.sign = sign;
function getSigningKey(mux, opts) {
    const keyId = opts.keyId || mux.jwtSigningKey;
    if (!keyId) {
        throw new Error('Signing key required; pass a keyId option to mux.jwt.sign*(), a jwtSigningKey option to new Mux(), or set the MUX_SIGNING_KEY environment variable');
    }
    return keyId;
}
exports.getSigningKey = getSigningKey;
async function getPrivateKey(mux, opts) {
    let key = await getPrivateKeyHelper(mux, opts);
    if (typeof key === 'string') {
        if (key.startsWith('-----BEGIN RSA PRIVATE')) {
            key = (0, jwt_util_1.toPkcs8Pem)((0, jwt_util_1.pkcs1to8)((0, jwt_util_1.unwrapPem)(key)));
        }
        return await (0, jose_1.importPKCS8)(key, 'RS256');
    }
    else if (key instanceof Uint8Array) {
        return await (0, jose_1.importPKCS8)((0, jwt_util_1.toPkcs8Pem)((0, jwt_util_1.pkcs1to8)(key)), 'RS256');
    }
    else if ((0, jwt_util_1.isKeyLike)(key)) {
        return key;
    }
    throw new TypeError(jwt_util_1.keyFormatErrorMessage);
}
exports.getPrivateKey = getPrivateKey;
async function getPrivateKeyHelper(mux, opts) {
    let key;
    if (opts.keySecret) {
        key = opts.keySecret;
    }
    else if (opts.keyFilePath) {
        throw new Error(`keyFilePath is not supported in this environment`);
    }
    else if (mux.jwtPrivateKey) {
        key = mux.jwtPrivateKey;
    }
    if ((0, jwt_util_1.isKeyLike)(key))
        return key;
    if (typeof key === 'string') {
        key = key.trim();
        if (key.startsWith('-----BEGIN')) {
            return key;
        }
        try {
            key = atob(key);
            if (key.startsWith('-----BEGIN')) {
                return key;
            }
        }
        catch (error) {
            // fallthrough
        }
        throw new TypeError(jwt_util_1.keyFormatErrorMessage);
    }
    throw new TypeError('Private key required; pass a keySecret option to mux.jwt.sign*(), a jwtPrivateKey option to new Mux(), or set the MUX_PRIVATE_KEY environment variable');
}
//# sourceMappingURL=jwt.js.map