import { type Agent } from "./_shims/index.js";
import * as Core from "./core.js";
import * as Errors from "./error.js";
import * as Pagination from "./pagination.js";
import { type BasePageParams, BasePageResponse, type PageWithTotalParams, PageWithTotalResponse } from "./pagination.js";
import * as Uploads from "./uploads.js";
import * as API from "./resources/index.js";
import { Webhooks } from "./resources/webhooks.js";
import { Data } from "./resources/data/data.js";
import { System } from "./resources/system/system.js";
import { Video } from "./resources/video/video.js";
export interface ClientOptions {
    /**
     * Defaults to process.env['MUX_TOKEN_ID'].
     */
    tokenId?: string | undefined;
    /**
     * Defaults to process.env['MUX_TOKEN_SECRET'].
     */
    tokenSecret?: string | undefined;
    /**
     * Defaults to process.env['MUX_WEBHOOK_SECRET'].
     */
    webhookSecret?: string | null | undefined;
    /**
     * Defaults to process.env['MUX_SIGNING_KEY'].
     */
    jwtSigningKey?: string | null | undefined;
    /**
     * Defaults to process.env['MUX_PRIVATE_KEY'].
     */
    jwtPrivateKey?: string | null | undefined;
    /**
     * Override the default base URL for the API, e.g., "https://api.example.com/v2/"
     *
     * Defaults to process.env['MUX_BASE_URL'].
     */
    baseURL?: string | null | undefined;
    /**
     * The maximum amount of time (in milliseconds) that the client should wait for a response
     * from the server before timing out a single request.
     *
     * Note that request timeouts are retried by default, so in a worst-case scenario you may wait
     * much longer than this timeout before the promise succeeds or fails.
     */
    timeout?: number | undefined;
    /**
     * An HTTP agent used to manage HTTP(S) connections.
     *
     * If not provided, an agent will be constructed by default in the Node.js environment,
     * otherwise no agent is used.
     */
    httpAgent?: Agent | undefined;
    /**
     * Specify a custom `fetch` function implementation.
     *
     * If not provided, we use `node-fetch` on Node.js and otherwise expect that `fetch` is
     * defined globally.
     */
    fetch?: Core.Fetch | undefined;
    /**
     * The maximum number of times that the client will retry a request in case of a
     * temporary failure, like a network error or a 5XX error from the server.
     *
     * @default 2
     */
    maxRetries?: number | undefined;
    /**
     * Default headers to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * header to `undefined` or `null` in request options.
     */
    defaultHeaders?: Core.Headers | undefined;
    /**
     * Default query parameters to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * param to `undefined` in request options.
     */
    defaultQuery?: Core.DefaultQuery | undefined;
}
/**
 * API Client for interfacing with the Mux API.
 */
export declare class Mux extends Core.APIClient {
    tokenId: string;
    tokenSecret: string;
    webhookSecret: string | null;
    jwtSigningKey: string | null;
    jwtPrivateKey: string | null;
    private _options;
    /**
     * API Client for interfacing with the Mux API.
     *
     * @param {string | undefined} [opts.tokenId=process.env['MUX_TOKEN_ID'] ?? undefined]
     * @param {string | undefined} [opts.tokenSecret=process.env['MUX_TOKEN_SECRET'] ?? undefined]
     * @param {string | null | undefined} [opts.webhookSecret=process.env['MUX_WEBHOOK_SECRET'] ?? null]
     * @param {string | null | undefined} [opts.jwtSigningKey=process.env['MUX_SIGNING_KEY'] ?? null]
     * @param {string | null | undefined} [opts.jwtPrivateKey=process.env['MUX_PRIVATE_KEY'] ?? null]
     * @param {string} [opts.baseURL=process.env['MUX_BASE_URL'] ?? https://api.mux.com] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL, tokenId, tokenSecret, webhookSecret, jwtSigningKey, jwtPrivateKey, ...opts }?: ClientOptions);
    video: API.Video;
    data: API.Data;
    system: API.System;
    webhooks: API.Webhooks;
    jwt: API.Jwt;
    protected defaultQuery(): Core.DefaultQuery | undefined;
    protected defaultHeaders(opts: Core.FinalRequestOptions): Core.Headers;
    protected authHeaders(opts: Core.FinalRequestOptions): Core.Headers;
    protected stringifyQuery(query: Record<string, unknown>): string;
    static Mux: typeof Mux;
    static DEFAULT_TIMEOUT: number;
    static MuxError: typeof Errors.MuxError;
    static APIError: typeof Errors.APIError;
    static APIConnectionError: typeof Errors.APIConnectionError;
    static APIConnectionTimeoutError: typeof Errors.APIConnectionTimeoutError;
    static APIUserAbortError: typeof Errors.APIUserAbortError;
    static NotFoundError: typeof Errors.NotFoundError;
    static ConflictError: typeof Errors.ConflictError;
    static RateLimitError: typeof Errors.RateLimitError;
    static BadRequestError: typeof Errors.BadRequestError;
    static AuthenticationError: typeof Errors.AuthenticationError;
    static InternalServerError: typeof Errors.InternalServerError;
    static PermissionDeniedError: typeof Errors.PermissionDeniedError;
    static UnprocessableEntityError: typeof Errors.UnprocessableEntityError;
    static toFile: typeof Uploads.toFile;
    static fileFromPath: typeof Uploads.fileFromPath;
}
export declare namespace Mux {
    export type RequestOptions = Core.RequestOptions;
    export import PageWithTotal = Pagination.PageWithTotal;
    export { type PageWithTotalParams as PageWithTotalParams, type PageWithTotalResponse as PageWithTotalResponse, };
    export import BasePage = Pagination.BasePage;
    export { type BasePageParams as BasePageParams, type BasePageResponse as BasePageResponse };
    export { Video as Video };
    export { Data as Data };
    export { System as System };
    export { Webhooks as Webhooks };
    export import Jwt = API.Jwt;
    export type PlaybackID = API.PlaybackID;
    export type PlaybackPolicy = API.PlaybackPolicy;
}
export { toFile, fileFromPath } from "./uploads.js";
export { MuxError, APIError, APIConnectionError, APIConnectionTimeoutError, APIUserAbortError, NotFoundError, ConflictError, RateLimitError, BadRequestError, AuthenticationError, InternalServerError, PermissionDeniedError, UnprocessableEntityError, } from "./error.js";
export default Mux;
//# sourceMappingURL=index.d.ts.map